# abas_client.rb
require 'json'

module AbasClient
  class Main
    def initialize(id_hash)
      @mname = id_hash['mname']
      @erp = id_hash['erp']
      @dockerized = @erp['dockerized']
      @container_name = @erp['container_name']
      @base_mandantdir = id_hash['base_mandantdir']
      @suffix_mandantdir = id_hash['suffix_mandantdir']
      if (@base_mandantdir.nil? || @base_mandantdir == '')
        @mandantdir = File.join(@erp['homebase'], @suffix_mandantdir)
      else
        @mandantdir = File.join(@base_mandantdir, @suffix_mandantdir)
      end
      @mandantdir_env_path = File.join(@erp['homedir'], "mandantdir.env")

      @mand_data = loadData() if exists?()
    end

    def exists?
        File.directory?(File.join(@mandantdir, "abasbase"))
    end

    def suffix_mandantdir
      return @mand_data['SUFFIX_MANDANTDIR']
    end

    def no_backup
      value = @mand_data['NO_BACKUP']

      if (value == '0' || value == nil)
        return false
      elsif value == '1'
        return true
      else
        return value
      end
    end

    def mandant
      return @mand_data['MANDANT']
    end

    private 

    def loadData
      if @dockerized
        mandantdir_env = `docker exec -t #{@container_name} cat #{@mandantdir_env_path}`.strip.gsub("\r", "").split("\n")
      else
        mandantdir_env = File.readlines(@mandantdir_env_path)
      end

      is_in_block = false
      result = Hash.new

      mandantdir_env.each do |raw_line|
        line = raw_line.partition("#")[0].strip
        next unless line.include? '='
        key = line.split('=')[0].strip
        value = line.split('=')[1].strip

        if is_in_block
          if key == 'END' && value == @mname
            break
          end

          result[key] = value
        else
          if key == 'BEGIN' && value == @mname
            is_in_block = true
          end
        end
      end

      return result
    end
  end
end