class client::install_native inherits client {

  if $create_mode == "ARCHIVE" {
    $archive_opt = "-a ${archive_file}"
  } else {
    $archive_opt = ""
  }

  if Integer($erp_version_year) > 2017 {
    $client_prog = 'create_mandant.sh'
  } else {
    $client_prog = 'mandinit.sh'
  }

  service { 'smbd':
  }

  service { 'xinetd':
  }

  exec { 'create client user':
    command => "$homedir/bin/erpUserPrepare.sh -u $mname -g $s3_group -t $homebase/$suffix_mandantdir",
    cwd => "$homedir",
    user => 'root',
    path => ['/bin', '/sbin', '/usr/sbin', '/usr/bin', '/usr/local/bin'],
  }->

  exec { 'configure client ssh':
    command => "/$homedir/bin/erpSSHPrepare.sh -u $mname -g $s3_group -s $s3_user",
    cwd => "$homedir",
    user => 'root',
    path => ['/bin', '/sbin', '/usr/sbin', '/usr/bin', '/usr/local/bin'],
  }->

  file { "${workdir}/mandantdir.env.part":
    ensure  => file,
    content => template("client/mandantdir_env_entry.erb"),
  }->

  exec { 'append mandantdir.env entry':
    command => "cat ${workdir}/mandantdir.env.part >> mandantdir.env",
    cwd => "$homedir",
    user => 'root',
    unless => "grep -E '^[[:space:]]*BEGIN[[:space:]]*=[[:space:]]*${mname}[[:space:]]*(#.*)*$' ${homedir}/mandantdir.env",
    path => ['/bin', '/sbin', '/usr/sbin', '/usr/bin', '/usr/local/bin'],
  }->

  exec { 'create client':
    command => "bash -c 'cd $homedir && eval $(sh ./denv.sh) && ${client_prog} -m $mname -i $create_mode $archive_opt > ${homebase}/create_mandant_${mname}.log 2>&1'",
    cwd => "$homedir",
    user => "$s3_user",
    logoutput   => 'on_failure',
    path => ['/bin', '/sbin', '/usr/sbin', '/usr/bin', '/usr/local/bin'],
    timeout => 1800,
  }->

  exec { 'fix permissions':
    command => "bash -c 'cd $homedir && eval $(sh ./denv.sh) && $homedir/bin/zugriff.sh -m $homebase/$suffix_mandantdir'",
    user => "root",
    path => ['/bin', '/sbin', '/usr/sbin', '/usr/bin', '/usr/local/bin'],
  }->

  exec { 'insert samba share':
    command => "/bin/echo \"include = ${homebase}/${suffix_mandantdir}/smb.conf\" >> /etc/samba/smb.conf",
    user    => 'root',
    notify  => [Service['smbd'],Service['xinetd']],
    onlyif  => '/usr/bin/test -e /etc/samba/smb.conf',
    unless  => "/bin/grep ${homebase}/${suffix_mandantdir}/smb.conf /etc/samba/smb.conf",
  }

  if $diag_email_config != undef {

    $smtp_server_name          = $diag_email_config['smtp_server_name']
    $smtp_server_port          = $diag_email_config['smtp_server_port']
    $sender_email_address      = $diag_email_config['sender_email_address']
    $recipient_sysfehl_address = $diag_email_config['recipient_sysfehl_address']
    $recipient_admfehl_address = $diag_email_config['recipient_admfehl_address']
    $smtp_server_login         = $diag_email_config['smtp_server_login']
    $smtp_server_passwd        = $diag_email_config['smtp_server_passwd']

    file { "${workdir}/mand.ini.sh":
      ensure  => file,
      content => template("client/mand.ini.sh.erb"),
      owner   => "$mname",
      mode    => '755',
      require => Exec['insert samba share'],
    }->

    exec { 'set MAND.INI parameter':
      command => "${workdir}/mand.ini.sh",
      user    => "$mname"
    }->

    file { "${workdir}/sysfehl.par.sh":
      ensure  => file,
      content => template("client/sysfehl.par.sh.erb"),
      owner   => "$mname",
      mode    => '755'
    }->

    exec { 'set SYSFEHL.PAR parameter':
      command => "${workdir}/sysfehl.par.sh",
      user    => "$mname"
    }->

    if $smtp_server_login != "" {
      file { "${workdir}/sysfehl.par.sec.sh":
        ensure  => file,
        content => template("client/sysfehl.par.sec.sh.erb"),
        owner   => "$mname",
        mode    => '755'
      }->

      exec { 'set SYSFEHL.PAR security parameter':
        command => "${workdir}/sysfehl.par.sec.sh",
        user    => "$mname"
      }
    }
  }
}
