class client_configuration::server_conf_native inherits client_configuration {

  #TODO: When available, switch to https://forge.puppet.com/puppetlabs/inifile

  $timestamp = $data['extras']['timestamp']

  $newConf = "${clientdir}/.server.conf.new"
  $oldConf = "${clientdir}/.server.conf"
  $confBackup = "${oldConf}.${timestamp}"

  # Prepare `setini' invocations. These are executed conditionally, if the external dependencies are set.

  if defined('$jwt_auth_userinfo_url') {
    $setSSO = "${setini} '${newConf}' SSO server '${jwt_auth_userinfo_url}' && \
${setini} '${newConf}' SSO verify_peer False && \
${setini} '${newConf}' SSO '; logfile' /tmp/sso.log"
  } else {
    $setSSO = "echo 'skipping SSO configuration'"
  }

  if defined('$license_controller_url') {
    $setLicenseControllerURL = "${setini} '${newConf}' LicenseController url '${license_controller_url}'"
  } else {
    $setLicenseControllerURL = "echo 'skipping license controller configuration'"
  }

  if defined('$installation_number') {
    $setInstallationNumber = "${setini} '${newConf}' LicenseController installation '${installation_number}'"
  } else {
    $setInstallationNumber = "echo 'skipping installation number configuration'"
  }

  file { "${clientdir}":
    ensure => 'directory',
  }

  -> exec { "Create a stage for the new server configuration":
    command   => "touch ${newConf}",
    path      => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
    logoutput => on_failure,
  }

  -> exec { "Adopt existing server configuration, if one exists":
    command   => "cp ${oldConf} ${newConf}",
    onlyif    => "test -f ${oldConf}",
    path      => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
    logoutput => on_failure,
  }

  exec { "Backup existing server configuraiton, if one exists":
    command   => "cp ${oldConf} ${confBackup}",
    onlyif    => "test -f ${oldConf}",
    path      => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
    logoutput => on_failure,
  }

  exec { "Configure SSO":
    command   => $setSSO,
    onlyif    => "test -f ${newConf}",
    path      => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
    logoutput => on_failure,
  }

  -> exec { "Configure License Controller URL":
    command   => $setLicenseControllerURL,
    path      => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
    logoutput => on_failure,
  }

  -> exec { "Configure instllation number":
    command   => $setInstallationNumber,
    path      => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
    logoutput => on_failure,
  }

  -> exec { "Adjust the file permissions on the new configuraiton file":
    command    => "chmod 664 ${newConf}",
    path      => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
    logoutput => on_failure,
  }

  -> exec { "Make the new configuration the current one":
    command   => "mv ${newConf} ${oldConf}",
    path      => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
    logoutput => on_failure,
  }

  -> exec { 'Adjust file permissions of the new configuration file to match those of the parent directory':
    command   => "chown --reference ${clientdir} ${oldConf}",
    path      => '/bin:/usr/bin',
    logoutput => on_failure,
  }
}
