module AbasDashboard
    class CheckFactory
      def initialize(data)
        @config = data['config']
        @install_dir = @config['install_dir']
        @registry_credentials = Abas::Credentials.load(@config['registry_credentials'])
        @mongodb_dashboard_credentials = Abas::Credentials.load(@config['mongodb_dashboard_credentials'])
      end

      def dashboard_service_port_free_check()
        Abas::PortCheck.create(
        name: "Check if activitiy service port is free", 
        port: @config['dashboard_api_port'], 
        free: true)
      end
  
      def install_dir_exists_check()
        Abas::FileCheck.create(
          name: "Check if install_dir exists", 
          path: @config['install_dir'], 
          should_exist: true)
      end
  
      def install_dir_not_exists_check()
        Abas::FileCheck.create(
          name: "Check if install_dir does not exist", 
          path: @config['install_dir'], 
          should_exist: false)
      end
  
      def docker_compose_exists_check()
        Abas::FileCheck.create(
          name: "Check if docker-compose.yml exists",
          path: "#{@install_dir}/docker-compose.yml",
          should_exist: true
        )
      end
  
      def disk_space_check()
        Abas::DiskCheck.create(
          name: "Check if install_dir has enough free space",
          path: @config['install_dir'],
          required_mb: 1024 * 2,
          recommended_mb: 1024 * 10
        )
      end
  
      def credential_check()
        Abas::CredentialCheck.create(
          name: "Check if credentials are valid",
          username: @registry_credentials['username'],
          password: @registry_credentials['password']
        )
      end

      def mongodb_credentials_check()
        Abas::CredentialCheck.create(
          name: "Check if mongodb credentials are valid",
          username: @mongodb_dashboard_credentials['username'],
          password: @mongodb_dashboard_credentials['password']
        )
      end
    end
  end