class dashboard(String $module_id) {

  $data = abas::inspect($module_id)

  $extra_hosts    = $data['hosts']

  $path           = $data['config']['name']
  $module_version = $data['metadata']['Version']
  $product_version= $data['version']
  $extra_data     = $data['extras']['extra_data']
  $install_dir    = $data['config']['install_dir']
  $dashboard_api_version = $data['extras']['api_version']
  $issuer = $data['config']['oauth2']['issuer']

  $mongodb_atlas_url = $data['extras']['mongodb_atlas_url']
  $dashboard_api_port = $data['config']['dashboard_api_port']

  $registry_credentials   = abas::credentials($data['config']["registry_credentials"])
  $registry_username      = $registry_credentials["username"]
  $registry_password      = $registry_credentials["password"]

  $user                   = $data['config']['user']

  user { "${user}":
    ensure     => 'present',
    name       => $user,
    managehome => true,
    groups     => ['docker']
  }

  -> exec { "Create directory: ${install_dir}":
    command => "mkdir -p ${install_dir}",
    onlyif  => "test ! -d ${install_dir}",
    path    => '/usr/bin:/bin'
  }
  -> file { $install_dir:
    ensure  => directory,
    owner   => $user,
    recurse => true,
  }

  -> exec { "DOCKER: Login user to docker.registry.abas.sh":
    onlyif    => ["[ ${registry_username} ] && [ ${registry_password} ] || exit 1"],
    command   => "docker login docker.registry.abas.sh -u '${registry_username}' -p '${registry_password}'",
    logoutput => true,
    user      => $user,
    path      => '/usr/bin',
    timeout   => 3600
  }
  -> file { "${install_dir}/docker-compose.yml":
    ensure  => file,
    content => template('dashboard/docker-compose.yml.erb'),
    mode    => '0440',
    owner   => $user,
  }
  -> file { "${install_dir}/VERSION":
     ensure  => file,
     content => template('dashboard/VERSION.erb'),
     mode    => '0500',
     owner   => $user,
  }
  -> exec { 'Start dashboard api container':
    command   => 'docker-compose up -d --force-recreate',
    user      => $user,
    path      => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
    logoutput => true,
    cwd       => $install_dir,
    timeout   => 3600
  }
  -> exec { 'DOCKER: Logout from docker.registry.abas.sh':
    command   => "docker logout docker.registry.abas.sh",
    logoutput => true,
    user      => $user,
    path      => '/usr/bin',
  }
}
