# abas_erp.rb

require 'etc'

module AbasErp

  project_dir = File.expand_path("..", File.dirname(__FILE__))
  require File.join(project_dir, 'custom/service_properties')

  class Main

    def initialize(id_hash)
      @id_hash = id_hash
      @homedir = id_hash['homedir']
      @datmod_servicefile_basename = id_hash['datmod_servicefile_basename']
    end

    def exists?
      return File.file? (File.join(@homedir, "00VERSION"))
    end

    def version
      File.read(File.join(@homedir, "00VERSION"))
    end

    def javapath
      return `cd #{@homedir} && eval $(sh denv.sh) && echo $JAVAPATH`
    end
    
    def dirname_s3
     `cd #{@homedir} && pwd`.split('/').last
    end

    def client_dirnames
      `cd #{@homedir} && eval $(sh denv.sh) && mandwahl.sh -q | tr -s " " | cut -d' ' -f 1 | tr '\n' ' '`
    end

    def client_usernames
      `cd #{@homedir} && eval $(sh denv.sh) && mandwahl.sh -q | tr -s " " | cut -d' ' -f 3 | tr '\n' ' '`.strip
    end

    def client_usernames_batch
      batch_users = ''
      client_usernames.split(' ').each { |user|
        batch_users << find_user_with_same_homedir(user)
        batch_users << ' '
      }
      return batch_users.strip
    end

    def ssh_port
      found_port = `grep "^Port" /etc/ssh/sshd_config | cut -d' ' -f 2`.strip

      if found_port != '' 
        return found_port
      else
        return 22
      end
    end

    def gui_port
      return datmod_port()
    end

    def s3_user
      `stat -c "%U" #{@homedir}`.strip
    end

    def group_name
      `id -g -n #{s3_user()}`
    end

    def group_number
      `id -g #{s3_user()}`
    end

    def archname
      `cd #{@homedir} && eval $(sh denv.sh) && archname.sh`.strip
    end

    def datmod_servicefile_path
      path=`grep includedir /etc/xinetd.conf | cut -d' ' -f 2`.strip
      if path.end_with? "/"
      else
        return path.concat("/")
      end
    end

    def username_help
      # `grep '#{@homedir}' /etc/passwd | grep -v '^#{s3_user()}' | cut -d':' -f 1`
      user=find_user_with_same_homedir(s3_user())
      if user == ''
        return 'not found'
      else
        return user
      end
    end

    def dirname_nobackup
      `cd #{@homedir} && eval $(sh denv.sh) && echo $NOBACKUP`.split('/').last
    end

    def datmod_port
      files = Array.new()
      Dir.foreach(datmod_servicefile_path()) do | file |
        files << ServiceProperties.new(File.join(datmod_servicefile_path(), file))
      end
      files.select! do | file |
        if ( @datmod_homedir.nil? || @datmod_homedir == '' )
          file.valid? && file.key?('server_args') && file.value('server_args').end_with?(@homedir)
        else
          file.valid? && file.key?('server_args') && file.value('server_args').end_with?(@datmod_homedir)
        end
      end
      datmod = files.first
      if ( datmod != nil )
        if datmod.key?('port')
          return datmod.value('port')
        else
          return 48392
        end
      end
      return ''
    end

    def hostname
      return `hostname -s`.strip
    end

    def edp
      return AbasErp::Edp.new(@id_hash)
    end

    private

    def find_user_with_same_homedir(user)
      homedir=find_user_homedir(user)
      Etc.passwd { |password|
        if password.dir == homedir
          if password.name != user
            return password.name
          end
        end
      }
      return '' # no user found
    end

    def find_user_homedir(user)
      Etc.passwd { |password|
        if password.name == user
          return password.dir
        end
      }
      return '' # no home found
    end
  end

  class Edp
    def initialize(id_hash)
      @homedir = id_hash['homedir']
    end

    def port

      # read homedir.env
      content = File.read(File.join(@homedir, "homedir.env"))

      settings = []
      # ignore comments
      content.each_line do |line|
        comment_start = line.index('#')
        if comment_start
          settings << line[0, comment_start].strip
        else
          settings << line.strip
        end
      end

      # filter for EDPPORT
      settings.select! do |s|
        s.match(/EDPPORT/)
      end

      if settings.empty?
        6550
      else
        settings[0].match(/(.*)=(.*)/)[2].strip
      end
    end

    def servicefile_path
      path_config = `grep '^includedir' /etc/xinetd.conf`

      path = path_config.split(' ').last.strip
      path = path.concat("/") unless path.end_with? "/"

      return path
    end

    def service_name
      `cd #{servicefile_path()} && grep -l 'server_args = -[iI] HOMEDIR=#{@homedir} PROT=EDP2' *`.strip
    end

    def hostname
      if File.file? (File.join(@homedir, "00VERSION"))
        return `hostname -s`.strip
      end
    end

  end
end
