class erp::install_native inherits erp {
  Exec { logoutput => on_failure, timeout => 600 }

  $installdir = '/opt/abas-installer-workdir/workdir/erp/INSTALL'
  $user = 'root'
  $cdftpdir = "CDftp-${version}"

  $add_repo_command = $::osfamily ? {
    'redhat'  => 'yum install -y https://dl.fedoraproject.org/pub/epel/epel-release-latest-7.noarch.rpm',
     default  => 'echo "nothing to do"',
  }

  $repo_condition = $::osfamily ? {
    'redhat'  => 'yum repolist | grep --silent "epel"',
     default  => 'echo "nothing to do"',
  }

  service { 'sshd':
    ensure  => 'running',
  }

  ->file { "${installdir}":
    ensure => 'directory',
    owner  => "${user}",
    mode   => '0777',
  }

  ->exec { 'install epel repository if on amazon linux 2':
    command => $add_repo_command,
    path    => ['/usr/bin','/bin'],
    onlyif  => 'grep --silent "Amazon Linux" /etc/os-release',
    unless  => $repo_condition,
  }

  ->exec { 'curl abas ERP Update base':
    command => "/usr/bin/curl -u ${registry_username}:${registry_password} -Ls https://registry.abas.sh/artifactory/abas.downloads/versions/${version}/erp-basepack-${version}.tgz -O",
    cwd     => "${installdir}",
    group   => "${user}",
    creates => "${installdir}/erp-basepack-${version}.tgz",
    path    => ['/usr/bin/X11', 'usr/bin'],
  }

  ->exec { 'wget abas ERP Update arch':
    command => "/usr/bin/curl -u ${registry_username}:${registry_password} -Ls https://registry.abas.sh/artifactory/abas.downloads/versions/${version}/erp-x86_64_linux-${version}.tgz -O",
    cwd     => "${installdir}",
    user    => "${user}",
    creates => "${installdir}/erp-x86_64_linux-${version}.tgz",
    path    => ['/usr/bin/X11', 'usr/bin'],
  }

  ->exec { 'unpack erp Update base':
    command => "/bin/tar xvzf ${installdir}/erp-basepack-${version}.tgz",
    cwd     => "${installdir}",
    user    => "${user}",
  }

  ->exec { 'unpack erp Update arch':
    command => "/bin/tar xvzf ${installdir}/erp-x86_64_linux-${version}.tgz",
    cwd     => "${installdir}",
    user    => "${user}",
  }

  ->file { "${installdir}/${cdftpdir}/bin/erpOSPrepare.cfg":
    ensure  => file,
    content => template('erp/erpOSPrepare.cfg.erb'),
  }

  ->exec { 'prepare OS':
    command     => "${installdir}/${cdftpdir}/bin/erpOSPrepare.sh -f -n -i",
    user        => "${user}",
    logoutput   => 'on_failure',
    path        => ['/usr/local/sbin', '/usr/local/bin', '/usr/sbin', '/usr/bin', '/sbin','/bin'],
    environment => ["ABAS_DIRNAME_MOUNT=${abasmountdir}", "JAVAPATH=${javapath}"],
  }

  ->file { "${abasmountdir}/${abasbasedir}":
    ensure  => 'directory',
    owner   => "${s3_user}",
    group   => "${group_name}",
    mode    => '775',
  }

  ->exec { 'install erp':
    command     => "${installdir}/${cdftpdir}/install-unix.sh -h ${homedir} -o > ${installdir}/install_unix.log 2>&1",
    cwd         => "${installdir}",
    user        => "${s3_user}",
    logoutput   => 'on_failure',
    path        => ['/usr/local/bin', '/usr/bin', '/bin', '/opt/puppetlabs/bin'],
    environment => ["HOME=${homedir}", "LOGNAME=${s3_user}", 'ALLOW_OPEN_JDK=1', "CUSTOM_CONFIG_YML=${abasmountdir}/${abasbasedir}/custom.config"],
    creates     => "${homedir}/00COMMIT",
    timeout     => 0
  }

  ->exec { 'install erp root script':
    command => "${homedir}/Messages/rootInstall/installAllScripts.sh",
    cwd     => "${homedir}",
    group   => 'root',
    user    => 'root',
    onlyif  => "/usr/bin/test -x ${homedir}/Messages/rootInstall/installAllScripts.sh",
    timeout => 900,
    path    => ['/usr/local/sbin', '/usr/local/bin', '/usr/sbin', '/usr/bin', '/sbin','/bin'],
  }

  ->exec { 'remove erp tar upgrade':
    command => "/bin/rm ${installdir}/erp-*.tgz",
    cwd     => "${installdir}",
    user    => "${user}",
  }
}

