#!/bin/bash
#------- ABSCHNITT : Modul Identifikation -------------------------------------
#
# Modul Name       : cloudsearch-update.sh
# .     Funktion   : Quicksearch for WebUI
# .     Verwendung : Full text search
# Autor            : uko
# Verantwortlich   : uko
#------------------------------------------------------------------------------

#------- ABSCHNITT : Defines, Prozeduren, Typen und Daten ---------------------
DEVNULL=${DEVNULL:-/dev/null}; export DEVNULL
name=`basename $0`
pwd=`pwd`
DIRNAME=$(dirname $(readlink -f $0))

#------------------------------------------------------------------------------
# Exit-Prozedur zum kontrollierten Beenden
# Parameter
#     $1 = Exit status
#     $2 = Fehlermeldung
#------------------------------------------------------------------------------
myexit()
{
  exitcode=$1
  errmsg=$2
  if [ -n "$errmsg" ];then
      echo "$name": "$errmsg" >&2
  fi
  exit $exitcode
}

#------- ABSCHNITT : Optionen -------------------------------------------------
# Options- und Nichtoptionsargumente koennen Blanks enthalten.

LIMIT=28
ERP_CLIENT="$pwd"
index=

while [ $# -gt 0 ]
do
  case $1 in
   -L) shift
       LIMIT="$1"
       ;;
   -m) shift
       ERP_CLIENT="$1"
       ;;
   -i) shift
       index="$1"
       ;;
  esac
  shift
done

source "$DIRNAME/common.sh"
fts_is_disabled && exit 0

if batchsperr.sh -p -t "install"; then exit 0; fi

# Allowed indexes
list="quicksearch"

if [ -z "$index" ]; then
  # indexlist.cfg exists
  if [ -e "$CLOUDMANDDIR/indexlist.cfg" ]; then
    cat $CLOUDMANDDIR/indexlist.cfg | grep -v '^#' | awk '$2=="1" {print $1}' | while read i; do
      batchsperr.sh -t "$i" -w -d 10 -x "$DIRNAME/$name -i $i -m \"$ERP_CLIENT\" -L $LIMIT" || myexit 1 "Could not update index $i."
    done
    myexit 0
  fi
  # indexlist.cfg does NOT exist
  for i in $list; do
    batchsperr.sh -t "$i" -w -d 10 -x "$DIRNAME/$name -i $i -m \"$ERP_CLIENT\" -L $LIMIT" || myexit 1 "Could not update index $i."
  done
  myexit 0
fi

if [[ -z "${list[$index]}" ]]; then
  myexit 1 "Only quicksearch allowed."
fi
if ! batchsperr.sh -p -t "$index"; then myexit 1 "Execution not allowed."; fi


#------------------------------------------------------------------------------

#
# Testen, ob benoetigte Datei da ist
if [ ! -f $COMMITFILE ]
then
    myexit 1 "File: $COMMITFILE not found"
else
    grep -v '^[0-9:.]*$' $COMMITFILE > $COMMITFILE.err
    if [ -s $COMMITFILE.err ] ; then
      myexit 1 "File: $COMMITFILE inconsistent $(cat $COMMITFILE.err)"
    fi
    rm $COMMITFILE.err
fi

# JAVA
[ -z "$JAVA" ] && JAVA=$(which java)
[ -z "$JAVA" ] && myexit 1 "Cannot find a Java JDK. Please set either set JAVA or put java (>=1.7) in your PATH."

echo "updating $index index"
# Normierte Feldliste ins DATA-Verzeichnis schreiben
feldliste -F $CONFIGDIR/$index.fields -n -O $DATABASEDIR/$index.normed 2>$DATABASEDIR/$index.errors
sed -i'' 's/ AS177 / AN177 /g' $DATABASEDIR/$index.normed

# Letzten CP einlesen & Inkrexport damit aufrufen um neue data-Datei zu erstellen.
# Exitcode 5 des inkrexport bedeutet, dass weitere Daten zum lesen vorhanden sind
MORE=5
while [ $MORE -eq 5 ]
do
  MORE=0
  echo "Starting point = " $(cat $COMMITFILE)
  inkrexport.sh -i -F $DATABASEDIR/$index.normed -I $(cat $COMMITFILE) -8 -v -L $LIMIT -S $COMMITFILE.neu > $DATADIR/data.inkrexport
  MORE=$?
    case $MORE in
       7) # Exitcode 7 des inkrexport.sh bedeutet, dass keine weiteren Daten zum lesen vorhanden waren
          mv $DATADIR/data.inkrexport $DATADIR/data
          myexit 0 "Nothing to do..."
          ;;
     0|5) # 5: mehr segmente, 0 das letzte Segment
         ;;
       *) # Fehlerfall wir lass data.inkrexport einfach liegen.
          # mv $DATADIR/data.inkrexport $DATADIR/data
          myexit $MORE "Inkrexport failed with: $MORE"
          ;;
    esac
  DATAFILESIZE=`ls -l $DATADIR/data.inkrexport | awk '{ print $5 }'`

  # Lucene Suchmaschine aufrufen

  echo "--job=index"
  mv $DATADIR/data.inkrexport $DATADIR/data.index || myexit 1 "mv failed: $DATADIR/data.inkrexport $DATADIR/data.store"

  if [ -e $CLOUDDIR/se-log.jar ]; then
    $JAVA -Xms512M -Xmx2G -jar $CLOUDDIR/se-log.jar LogIndexer \
      --job=index \
      --input=$DATADIR/data.index \
      --output=$LUCENEDIR \
      --client="$MANDANT" \
      --fields=$CONFIGDIR/$index.fields \
      --spec=$CONFIGDIR/$index.mapping \
      --link=$CONFIGDIR/polymorphic.references \
    || myexit 1 "Error updating index."
  else
    myexit 1 "Error updating index. se-log.jar not found."
  fi
  
  mv $COMMITFILE.neu $COMMITFILE || myexit 1 "mv failed: $COMMITFILE.neu $COMMITIFLE"

  rm $DATADIR/data.index || myexit 1 "rm failed: $DATADIR/data.index"
done

# Jetty refresh
JETTYERR=$JETTY_BASE/jetty.err
JETTYHOST="localhost" # has to be localhost!
JETTYPORT=
[ -s $JETTY_BASE/jetty.port ] && JETTYPORT=`cat $JETTY_BASE/jetty.port` # get runnig jetty port
[ ! -z $JETTYPORT ] && curl --noproxy $JETTYHOST -o $JETTYERR -s http://$JETTYHOST:$JETTYPORT/$index/closeSearchers > $DEVNULL

myexit 0
