#!/bin/bash
#------- ABSCHNITT : Modul Identifikation -------------------------------------
#
# Modul Name       : cloudsearch.sh
# .     Funktion   : Quicksearch for WebUI
# .     Verwendung : Volltextsuche
# Autor            : uko
# Verantwortlich   : uko
#------------------------------------------------------------------------------

#------- ABSCHNITT : Defines, Prozeduren, Typen und Daten ---------------------
name=`basename $0`
pwd=`pwd`
DIRNAME=$(dirname $(readlink -f $0))

#------------------------------------------------------------------------------
# Exit-Prozedur zum kontrollierten Beenden
# Parameter
#     $1 = Exit status
#     $2 = Fehlermeldung
#------------------------------------------------------------------------------
myexit()
{
  exitcode=$1
  errmsg=$2
  if [ -n "$errmsg" ];then
      echo "$name": "$errmsg" >&2
  fi
  exit $exitcode
}

#------- ABSCHNITT : Optionen -------------------------------------------------
# Options- und Nichtoptionsargumente koennen Blanks enthalten.
ERP_CLIENT="$pwd"
sperre=

while [ $# -gt 0 ]
do
  case $1 in
   -m) shift
       ERP_CLIENT="$1"
       ;;
   -s) sperre="sperre"
  esac
  shift
done

source "$DIRNAME/common.sh"

if [ -z "$sperre" ]; then
  batchsperr.sh -t "install" -w -d 10 -x "$DIRNAME/$name -m \"$ERP_CLIENT\" -s" || myexit 1 "Could not install."
  myexit 0
fi

if ! batchsperr.sh -p -t "install"; then myexit 0; fi

# Protokoll Versionsnummer
VERSIONNUMBER="{P 025 }"

#------- ABSCHNITT : Hauptprogramm --------------------------------------------

[ -e "$CLOUDDIR/bin/fts-jetty.sh" ] && "$CLOUDDIR/bin/fts-jetty.sh" -stop 1>/dev/null 2>&1

echo "$name: cleaning cloudmanddir"
PORT=
if [ -e "$CLOUDMANDDIR/fts-cloudsearch.port" ]; then
  PORT=`cat $CLOUDMANDDIR/fts-cloudsearch.port`     || myexit $?
fi
rm -rf $CLOUDMANDDIR/*                              || myexit $?

echo "$name: installing JETTY_BASE"
mkdir -p $JETTY_BASE                                || myexit $?
chmod -R 777 $JETTY_BASE                            || myexit $?
if [ ! -z "$PORT" ]; then
  echo "$PORT" > $CLOUDMANDDIR/fts-cloudsearch.port || myexit $?
fi
cp -R $CLOUDDIR/templates/jetty/* $JETTY_BASE       || myexit $?
mkdir -p $JETTY_BASE/webapps                        || myexit $?
cp $CLOUDDIR/se-ws.war $JETTY_BASE/webapps/quicksearch.war  || myexit $?
mkdir -p $JETTY_BASE/logs                           || myexit $?
if [ -e "$CLOUDDIR/bin/indexlist.cfg" ]; then
  cp $CLOUDDIR/bin/indexlist.cfg $CLOUDMANDDIR/indexlist.cfg || myexit $?
fi

# use SCHEMADB mode for epi
export PATESTFLAGGEN="-S"

# #################################
# CONFIG FILES
# #################################
mkdir -p $CONFIGDIR || myexit 1 "Couldn't create directory $CONFIGDIR"

# ###
echo "$name: generating file polymorphic.references"
# polymorphic.references
if [ ! -e $CONFIGDIR/polymorphic.references ]; then
  for i in `edpexport.sh -P -a VV | cut -d ';' -f1`; do edpexport.sh -P -a v -l $i | awk -v vp=$i 'BEGIN {FS = ";"}; {print vp" "$1":"$3}'; done | awk 'NF>1{a[$2] = a[$2]" "$1};END{for(i in a)print i""a[i]}' | sort -n -k1 > $CONFIGDIR/polymorphic.references       || myexit $?
fi

# ###
# quicksearch
echo "$name: quicksearch configuration"

rmdir=rmtmp/feldliste$$
mkdir -p $rmdir
# Feldliste erzeugen
tdattab -A | awk '$9 != "-"  { print $1, $2, $3, $7, $8, substr($9, 3)}' > $rmdir/feldliste.alle
awk 'BEGIN {
    db=-1;grp=0;tab=0;skip=0;name="";art="";
    '$(grep FELDLISTE_VERSION ${HOMEDIR}/bin/datentab.var)'
     merk = sprintf("# P %03d", FELDLISTE_VERSION)
}
function printmerk () {
    if (merk != "" && skip == "0") {
        if (substr(name, length(name)-3) == "bspr") {
            for (i = 1; i <= 32; i++) {
                print db " " grp " " tab " " substr(name, 1, length(name)-4) i " " art
            }
        } else {
            print merk
        }
        merk = ""
    }
}
{
    if (db == "-1") {
        printmerk()
    }
    # Gruppenwechsel
    if (db != $1 || grp != $2 || tab != $3) {
        db = $1; grp = $2; tab = $3;
    }
    art = $5;
    # Sucherweiterung der Gruppe gefunden
    if (db == $1 && grp == $2 && tab == $3 && $6 == "sucherw") {
      printmerk()
    }
    name = $6;
    # Merker
    merk = db " " grp " " tab " " name " " art
    # Kenner fuer Skipfelder
    if (substr($4, 1, 1) == "S" && substr(name, length(name)-3) != "bspr") {
      skip=1;
    } else {
      skip=0;
    }
    # nummer, such, objgruppe, objinzeile (skip!), objdnr
    if (db == $1 && grp == $2 && tab == $3 && (name == "nummer" || name == "such" || name == "objgruppe" || name == "objinzeile" || name == "objdnr")) {
      printmerk()
    }
}' $rmdir/feldliste.alle > $CONFIGDIR/quicksearch.fields || myexit 1 "Feldliste konnte nicht erzeugt werden."

# Feldlist ohne Versions-Zeile
tail -n +2 $CONFIGDIR/quicksearch.fields > $CONFIGDIR/quicksearch.fields.4mapping || myexit 1 "Mapping-Feldliste konnte nicht erzeugt werden."

### Mapping Datei erzeugen
# Praefixsuche mit WebclientPrefixAnalyzerFactory2 (2!)
echo -n 'key_word HEAD YES Key - NO -'                                                      >> $CONFIGDIR/quicksearch.mapping
awk '(/ nummer / || / such /){printf " %s", (NR);}' $CONFIGDIR/quicksearch.fields.4mapping  >> $CONFIGDIR/quicksearch.mapping
awk 'BEGIN { print "\n" }'                                                                  >> $CONFIGDIR/quicksearch.mapping
echo -n 'word HEAD YES Text de.abas.lucene.analysis.WebclientPrefixAnalyzerFactory2 NO -'   >> $CONFIGDIR/quicksearch.mapping
awk '!(/ objgruppe / || / objinzeile / || / objdnr /){printf " %s", (NR);}' $CONFIGDIR/quicksearch.fields.4mapping  >> $CONFIGDIR/quicksearch.mapping
awk 'BEGIN { print "\n" }'                                                                  >> $CONFIGDIR/quicksearch.mapping
# Präfix mit Feld prefix
echo -n 'key_prefix HEAD YES Key - NO -'                                                    >> $CONFIGDIR/quicksearch.mapping
awk '(/ nummer / || / such /){printf " %s", (NR);}' $CONFIGDIR/quicksearch.fields.4mapping  >> $CONFIGDIR/quicksearch.mapping
awk 'BEGIN { print "\n" }'                                                                  >> $CONFIGDIR/quicksearch.mapping
echo -n 'prefix HEAD YES Text de.abas.lucene.analysis.WebclientPrefixAnalyzerFactory2 NO -' >> $CONFIGDIR/quicksearch.mapping
awk '!(/ objgruppe / || / objinzeile / || / objdnr /){printf " %s", (NR);}' $CONFIGDIR/quicksearch.fields.4mapping  >> $CONFIGDIR/quicksearch.mapping
awk 'BEGIN { print "\n" }'                                                                  >> $CONFIGDIR/quicksearch.mapping
# objgruppe
echo -n 'objgruppe HEAD YES Key - NO -'                                                     >> $CONFIGDIR/quicksearch.mapping
awk '/ objgruppe /{printf " %s", (NR);}' $CONFIGDIR/quicksearch.fields.4mapping             >> $CONFIGDIR/quicksearch.mapping
awk 'BEGIN { print "\n" }'                                                                  >> $CONFIGDIR/quicksearch.mapping
# objinzeile
echo -n 'objinzeile HEAD YES Key - NO -'                                                    >> $CONFIGDIR/quicksearch.mapping
awk '/ objinzeile /{printf " %s", (NR);}' $CONFIGDIR/quicksearch.fields.4mapping            >> $CONFIGDIR/quicksearch.mapping
awk 'BEGIN { print "\n" }'                                                                  >> $CONFIGDIR/quicksearch.mapping
# objdnr
echo -n 'objdnr HEAD YES Key - NO -'                                                        >> $CONFIGDIR/quicksearch.mapping
awk '/ objdnr /{printf " %s", (NR);}' $CONFIGDIR/quicksearch.fields.4mapping                >> $CONFIGDIR/quicksearch.mapping
awk 'BEGIN { print "\n" }'                                                                  >> $CONFIGDIR/quicksearch.mapping
# Nummer (num)
echo -n "key_nummer HEAD YES Key - NO -"                                                    >> $CONFIGDIR/quicksearch.mapping
awk '/ nummer /{printf " %s", (NR);}' $CONFIGDIR/quicksearch.fields.4mapping                >> $CONFIGDIR/quicksearch.mapping
awk 'BEGIN { print "\n" }'                                                                  >> $CONFIGDIR/quicksearch.mapping
echo -n "nummer HEAD YES Key de.abas.lucene.analysis.WebclientPrefixAnalyzerFactory2 NO -"  >> $CONFIGDIR/quicksearch.mapping
awk '/ nummer /{printf " %s", (NR);}' $CONFIGDIR/quicksearch.fields.4mapping                >> $CONFIGDIR/quicksearch.mapping
awk 'BEGIN { print "\n" }'                                                                  >> $CONFIGDIR/quicksearch.mapping
# Suchwort (such)
echo -n "key_such HEAD YES Key - NO -"                                                      >> $CONFIGDIR/quicksearch.mapping
awk '/ such /{printf " %s", (NR);}' $CONFIGDIR/quicksearch.fields.4mapping                  >> $CONFIGDIR/quicksearch.mapping
awk 'BEGIN { print "\n" }'                                                                  >> $CONFIGDIR/quicksearch.mapping
echo -n "such HEAD YES Key de.abas.lucene.analysis.WebclientPrefixAnalyzerFactory2 NO -"    >> $CONFIGDIR/quicksearch.mapping
awk '/ such /{printf " %s", (NR);}' $CONFIGDIR/quicksearch.fields.4mapping                  >> $CONFIGDIR/quicksearch.mapping
awk 'BEGIN { print "\n" }'                                                                  >> $CONFIGDIR/quicksearch.mapping

# Aufraeumen
rm $CONFIGDIR/quicksearch.fields.4mapping


# ###############################
# INDEX CREATE - INITIAL
# ###############################

# JAVA
[ -z "$JAVA" ] && JAVA=$(which java)
[ -z "$JAVA" ] && myexit 1 "Cannot find a Java JDK. Please set either set JAVA or put java (>=1.7) in your PATH."
if [ -e $CLOUDDIR/se-log.jar ]; then
  # ###
  # dictionary index
  echo "$name: dictionary index"

  # db group data
  mkdir -p ${DIC_DATADIR} || myexit 1 "Couldn't create directory $DIC_DATADIR"
  edpexport.sh -P -a GA | awk 'BEGIN {FS = ";"}; {print "(GROUP,"$2":"$4")\t"$2":"$4}' > ${DIC_DATADIR}/data
  # create index
  echo "create dictionary index"
  $JAVA -jar $CLOUDDIR/se-log.jar TSVIndexer \
      --input=${DIC_DATADIR}/data \
      --output=${DIC_DATADIR}/lucene \
      --fields=$CLOUDDIR/templates/config/dictionary.fields \
      --spec=$CLOUDDIR/templates/config/dictionary.mapping \
    || myexit 1 "Error creating dictionary index"

  # ###
  # quicksearch
  echo "$name: quicksearch index"
  # Ausgabeverzeichnis fuer inkrexport anlegen falls nicht vorhanden
  mkdir -p ${QUICK_DATADIR}/increxport || myexit 1 "Couldn't create directory $QUICK_DATADIR/increxport"
  # Ausgabeverzeichnis leeren, falls Daten vorhanden
  rm -rf ${QUICK_DATADIR}/increxport/*
  # Datendatei mit Versionsnummer anlegen
  echo $VERSIONNUMBER > ${QUICK_DATADIR}/increxport/data || myexit 1 "Couldn't write to $QUICK_DATADIR/increxport/data."
  # Commitpunkt auf 0:0:0 festlegen
  echo "0:0:0" > ${QUICK_DATADIR}/lastcommit || myexit 1 "Couldn't write to $QUICK_DATADIR/lastcommit."
  # Indexverzeichnis anlegen, falls nicht vorhanden
  mkdir -p ${QUICK_DATADIR}/lucene || myexit 1 "Couldn't create parent directories: ${QUICK_DATADIR}/lucene."
  # Indexverzeichnis leeren, falls Daten vorhanden
  rm -rf ${QUICK_DATADIR}/lucene/*
  # LogIndexer
  echo "$name: create quicksearch index"
  $JAVA -jar $CLOUDDIR/se-log.jar LogIndexer \
      --job=meta \
      --input=${QUICK_DATADIR}/increxport/data \
      --output=${QUICK_DATADIR}/lucene \
      --client="$MANDANT" \
      --fields=$CONFIGDIR/quicksearch.fields \
      --spec=$CONFIGDIR/quicksearch.mapping \
    || myexit 1 "Error building initial meta data for quicksearch"
else
  myexit 1 "Error updating index. $CLOUDDIR/se-log.jar not found."
fi

myexit 0
