#!/bin/bash
#------- ABSCHNITT : Modul Identifikation -------------------------------------
#
# Modul Name       : cloudsearch.sh
# .     Funktion   : Jetty Server
# .     Verwendung : Full Text Search
# Autor            : uko
# Verantwortlich   : uko
#------------------------------------------------------------------------------

#------- ABSCHNITT : Defines, Prozeduren, Typen und Daten ---------------------
name=`basename $0`
pwd=`pwd`
DIRNAME=$(dirname $(readlink -f $0))

#------------------------------------------------------------------------------
# Exit-Prozedur zum kontrollierten Beenden
# Parameter
#     $1 = Exit status
#     $2 = Fehlermeldung
#------------------------------------------------------------------------------
myexit()
{
  exitcode=$1
  errmsg=$2
  if [ -n "$errmsg" ];then
      echo "$name": "$errmsg" >&2
  fi
  exit $exitcode
}

# #######################
# check binary files
# #######################
function check_md5sum() {
  local file="$1"
  local md5_1="$2"
  if [ -f "$file" ]; then
    local md5_2=$(md5sum -b "${file}" | cut -d' ' -f1)
    [ "${md5_1}" == "${md5_2}" ] || rm -f "${file}"
  fi
}

#------- ABSCHNITT : Optionen -------------------------------------------------
# Options- und Nichtoptionsargumente koennen Blanks enthalten.
sperre=

while [ $# -gt 0 ]
do
  case $1 in
   -s) sperre="sperre"
  esac
  shift
done

cd $HOMEDIR       || myexit $?
eval `sh denv.sh` || myexit $?

if [ -z "$sperre" ]; then
  batchsperr.sh -t "installserver" -i -w -d 10 -x "$DIRNAME/$name -s" || myexit 1 "Could not install."
  myexit 0
fi

if ! batchsperr.sh -i -p -t "installserver"; then myexit 0; fi

NOBACKUP_HOMEDIR=$(envmake -m $HOMEDIR -q NOBACKUP)
CLOUDDIR="$NOBACKUP_HOMEDIR/cloudsearch"
mkdir -p "$NOBACKUP_HOMEDIR"

JETTY_HOME=$CLOUDDIR/jetty-dist

#------- ABSCHNITT : Hauptprogramm --------------------------------------------

dist_file="$CLOUDDIR/jetty-dist.zip"
se_log_file="$CLOUDDIR/se-log.jar"
se_ws_file="$CLOUDDIR/se-ws.war"

check_md5sum "$dist_file" 3b1750297afd87e505e0b16133047942
check_md5sum "$se_log_file" ac5b55a4ced4dd0f525175b593d77fb4
check_md5sum "$se_ws_file" c178d40775450cfaeb985718fae9603c

server=
if [ ! -f "$dist_file" ]; then
  curl https://repo1.maven.org/maven2/org/eclipse/jetty/jetty-distribution/9.4.8.v20171121/jetty-distribution-9.4.8.v20171121.zip -L -o "$dist_file"
  server="install"
fi
if [ ! -f "$se_log_file" ]; then
  curl https://registry.abas.sh/repository/abas.maven-public/de/abas/se/log/se-log/17.1.1/se-log-17.1.1-onejar.jar -L -o "$se_log_file"
fi
if [ ! -f "$se_ws_file" ]; then
  curl https://registry.abas.sh/repository/abas.maven-public/de/abas/se/ws/se-ws/17.1.1/se-ws-17.1.1.war -L -o "$se_ws_file"
fi

# ###############################
# FTS - Jetty distribution
# ###############################
if [ -d "$JETTY_HOME" -a -z "$server" ]; then
  echo "FTS server up-to-date."
  exit 0
fi

echo "$name: stopping jetty"
for mand in `mdir.sh`; do
  (cd $mand; eval `sh ./denv.sh`; rm -f $CLOUDDIR/$MNAME/version; $CLOUDDIR/bin/fts-jetty.sh -stop 1>/dev/null 2>&1)
done

# #################################
# Jetty Distribution Installation
# #################################
if [ ! -e $JETTY_HOME ]; then
  echo "$name: installing JETTY_HOME"
  rm -rf $JETTY_HOME                                  || myexit $?
  unzip -n -q $CLOUDDIR/jetty-dist.zip -d $CLOUDDIR   || myexit $?
  mv $CLOUDDIR/jetty-distribution* $JETTY_HOME        || myexit $?
  chmod -R 777 $JETTY_HOME                            || myexit $?
fi

myexit 0
