#!/bin/bash -e

# this script will be executed on the tenant
# expects the erp client directory to install to in the environment variable ERP_CLIENT

DIRNAME=$(dirname $(readlink -f $0))
chmod +x *.sh
source "$DIRNAME/bin/common.sh"
fts_is_disabled && DISABLED=1
cd $DIRNAME

if [ -n "$HTTP_PROXYHOST" -a -n "$HTTP_PROXYPORT" ]; then
  if [ -z "$http_proxy" ]; then
    export http_proxy="http://${HTTP_PROXYHOST}:${HTTP_PROXYPORT}"
  fi
  if [ -z "$https_proxy" ]; then
    export https_proxy="http://${HTTP_PROXYHOST}:${HTTP_PROXYPORT}"
  fi
fi

rm -rf "$CLOUDDIR/bin"
mkdir -p "$CLOUDDIR/bin"
cp -R . "$CLOUDDIR/"
mkdir -p "$CLOUDMANDDIR/log"
# copy files
rm -f "$CLOUDDIR/install.sh"

$DIRNAME/bin/fts-server-install.sh

# ###############################
# FTS installation
# ###############################

UP_TO_DATE=0
# fts - check version
# TODO: option for re-installation ??
if [ -e "$CLOUDMANDDIR/version" ]; then
  version_old=$(cat "$CLOUDMANDDIR/version")
  version_new=$(cat "$DIRNAME/version")
  if [ "$version_old" == "$version_new" ]; then
    echo "FTS installation is up to date."
    UP_TO_DATE=1
  fi
fi

PORT_FILE="$CLOUDMANDDIR/fts-cloudsearch.port"
# start search engine if not already started
if [ ! -s "$PORT_FILE" ]; then
  if [ -n "$FTS_PORT" ]; then
    echo "$FTS_PORT" > "$PORT_FILE"
  elif [ "$FTS_USE_VTS_PORT" == "true" ]; then
    echo "$VTS_PORT" > "$PORT_FILE"
  else
    set +e
    command -v python >/dev/null 2>&1
    ex=$?
    set -e
    if [ $ex -ne 0 ]; then
      echo "Python is required. Please install it on erp machine (e.g. apt install python or yum install python)." 1>&2
      exit 1
    fi
    python -c 'import socket; s=socket.socket(); s.bind(("", 0)); print(s.getsockname()[1]); s.close()' > "$PORT_FILE"
  fi
fi

FTS_PORT=$(cat "$PORT_FILE")

if [ $UP_TO_DATE -eq 0 ]; then
  echo "##### Install FTS"
  cd $ERP_CLIENT
  $CLOUDDIR/bin/fts-jetty.sh -stop 1>/dev/null 2>&1 || true
  $CLOUDDIR/bin/fts-cloudsearch.sh

  # install crontab job if not already installed
  echo "##### Install FTS crontab job"
  echo ""
  echo "Please make sure that the kernel option 'fs.protected_hardlinks' is disabled."
  echo "Otherwise the cron job which updates the index will fail with 'Operation not permitted'."
  echo "To disable it add the following line to /etc/sysctl.conf:"
  echo ""
  echo "fs.protected_hardlinks=0"
  echo ""
  echo "Then run 'sysctl -p' to make it effective."

  set +e
  # also remove old quicksearch entry
  (crontab -l 2>/dev/null | grep -v "# fts-cloudsearch $ERP_CLIENT" | grep -v "# fts-quicksearch $ERP_CLIENT"; echo '* * * * * cd '"$ERP_CLIENT"'; eval `sh ./denv.sh`; mkdir -p '"$CLOUDMANDDIR"'/log; '"$CLOUDDIR"'/bin/fts-cloudsearch-update.sh > '"$CLOUDMANDDIR"'/log/fts-cloudsearch.log 2>&1 # fts-cloudsearch '"$ERP_CLIENT"'') | crontab -
  set -e

  # Copying version file to client
  cp "$DIRNAME/version" "$CLOUDMANDDIR/version"
fi
# just to make sure it is still disabled even after an update
if [ "$DISABLED" == "1" ]; then
  disable_fts
fi
echo "##### FTS installation for $ERP_CLIENT finished."
exit 0
