# abas_jwt_auth_userinfo.rb
require 'yaml'

module AbasJwt_auth_userinfo
  class Main

    def initialize(id_hash)
      @install_dir = id_hash['install_dir']
      if File.exists?(File.join(@install_dir, "/docker-compose.yml"))
        @docker_compose = loadDockerCompose
      else
        @docker_compose = {}
      end
    end

    def product_version
      return File.read("#{@install_dir}/VERSION").strip
    end

    def exists?()
      if (File.file?(File.join(@install_dir, "/.env")) &&
          File.file?(File.join(@install_dir, "/service.sh")) &&
          File.file?(File.join(@install_dir, "/VERSION")) &&
          File.file?(File.join(@install_dir, "/docker-compose.yml")) &&
          File.file?(File.join(@install_dir, "/service-defaults.env")))
        return true
      end
      return false
    end

    def user
      if File.exists?("#{@install_dir}")
        uid = File.stat("#{@install_dir}").uid
        return Etc.getpwuid(uid).name
      end
      return "Install directory not found."
    end

    def port
      return @docker_compose.dig('services', 'jwt-auth-userinfo', 'ports')[0].split(':')[0]
    end

    def project_name
      return `COMPOSE_PROJECT_NAME=unknown && . "#{@install_dir}/.env" && echo -n $COMPOSE_PROJECT_NAME`
    end

    def loglevel
      return `LOG_LEVEL=unknown && . "#{@install_dir}/service-defaults.env" && -n echo $LOG_LEVEL`
    end

    def erp_permissions
      return `JWT_AUTH_USERINFO_PERMISSIONS=unknown && . "#{@install_dir}/service-defaults.env" && echo -n $JWT_AUTH_USERINFO_PERMISSIONS`
    end

    def authentication
      obj = Hash.new
      erp = Hash.new
      erp[:username] = `ABAS_USERNAME=unknown && . "#{@install_dir}/service-defaults.env" && echo -n $ABAS_USERNAME`
      erp[:password] = `ABAS_PASSWD=unknown && . "#{@install_dir}/service-defaults.env" && echo -n $ABAS_PASSWD`
      obj[:erp_credentials] = erp
      return obj
    end

    def erp_workspaces
      return `JWT_AUTH_USERINFO_WORKSPACES=unknown && . "#{@install_dir}/service-defaults.env" && echo -n $JWT_AUTH_USERINFO_WORKSPACES`
    end

    def rest_api
      # abas-installer does not support factlibs of dependencies
      # some values of the dependency could be state, some could be control
      return "Factlibs of dependencies not implemented in abas-installer"
    end

    def authentication
      return "Factlibs of dependencies not implemented in abas-installer"
    end

    private

    def loadDockerCompose
      begin
        return YAML.load_file(File.join(@install_dir, "/docker-compose.yml"))
      rescue
        return {}
      end
    end

  end
end
