# Common install update steps for jwt_auth_userinfo
define jwt_auth_userinfo::install($data) {

  $config         = $data['config']
  $user           = $config['user']
  $install_dir    = $config['install_dir']
  $product_version= $data['version']

  $module_version = $data['metadata']['Version']
  $extra_data     = $data['extras']['extra_data']
  $extra_hosts    = $data['hosts']

  $port = $config['port']
  $project_name = $config['project_name']
  $docker_image = "docker.registry.abas.sh/jwt-auth-userinfo:${product_version}"
  $loglevel = $config['loglevel']
  $audience = $config['oauth2']['audience']
  $issuer = $config['oauth2']['issuer']
  $oidcd_configuration_url = $config['oauth2']['oidc_configuration_url']
  $jwt_auth_userinfo_port = $config['port']
  $user_sync_mode = $config['user_sync_mode']
  $erp_permissions = $config['erp_permissions']
  $erp_workspaces = $config['erp_workspaces']
  $rest_api_protocol = $config['rest_api']['protocol']
  $rest_api_host = $config['rest_api']['host']
  $rest_api_port = $config['rest_api']['port']

  $authentication     = $config['authentication']
  $erp_credentials   = abas::credentials($authentication['erp_credentials'])
  $erp_username = $erp_credentials["username"]
  $erp_password = $erp_credentials["password"]

  if ($authentication != undef) and ($authentication["registry_credentials"] != undef) {
      $registry_credentials   = abas::credentials($authentication["registry_credentials"])
      $registry_username      = $registry_credentials["username"]
      $registry_password      = $registry_credentials["password"]
  } else {
      $registry_username      = ''
      $registry_password      = ''
  }

  file { "${install_dir}/VERSION":
    ensure  => file,
    content => template('jwt_auth_userinfo/VERSION.erb'),
    mode    => '0500',
    owner   => $user,
  }

  -> file { "${install_dir}/docker-compose.yml":
    ensure  => file,
    content => template('jwt_auth_userinfo/docker-compose.yml.erb'),
    owner   => $user,
  }

  -> file { "${install_dir}/.env":
    ensure  => file,
    content => template('jwt_auth_userinfo/.env.erb'),
    owner   => $user,
  }

  -> file { "${install_dir}/service-defaults.env":
    ensure  => file,
    content => template('jwt_auth_userinfo/service-defaults.env.erb'),
    owner   => $user,
  }

  -> file { "${install_dir}/service.sh":
    ensure  => file,
    content => template('jwt_auth_userinfo/service.sh.erb'),
    mode    => '0500',
    owner   => $user,
  }

  -> exec { 'DOCKER: Login user to docker.registry.abas.sh':
    onlyif    => ["[ -n '${registry_username}' ] && [ -n '${registry_password}' ]"],
    command   => "docker login docker.registry.abas.sh -u '${registry_username}' -p '${registry_password}'",
    logoutput => true,
    user      => $user,
    path      => '/usr/bin',
  }

  -> file { "${install_dir}/logs":
    ensure  => directory,
    owner   => $user,
    recurse => true,
  }

  -> exec { 'Change ownership of install directory':
    command => "chown -R ${user} ${install_dir}",
    path    => '/usr/bin:/bin:/usr/local/bin',
    cwd     => $install_dir,
  }

  -> exec { 'Run jwt authentication and userinfo container':
    command   => './service.sh --up',
    path      => "/usr/bin:/bin:/usr/local/bin:${install_dir}",
    cwd       => $install_dir,
    user      => $user,
    logoutput => true,
  }

  -> exec { 'DOCKER: Logout from docker.registry.abas.sh':
    onlyif    => ["[ -n '${registry_username}' ] && [ -n '${registry_password}' ]"],
    command   => 'docker logout docker.registry.abas.sh',
    logoutput => true,
    user      => $user,
    path      => '/usr/bin',
  }
}
