module AbasKeycloak
  class Extras
    attr_reader :master_realm_endpoint, :docker_compose_keycloak_service_name, :docker_compose_keycloak_postgres_service_name,
                :certificate_subject_value, :abas_bpm_clientid, :abas_webclient_clientid, :abas_dashboard_clientid, 
                :abas_gui_clientid, :abas_user_management_service_clientid
                

    def initialize(module_data)
        @config = module_data['resolved_config']
        @host   = module_data['host']
        @docker_compose_keycloak_service_name          = AbasKeycloak::Constants::DOCKER_COMPOSE_KEYCLOAK_SERVICE_NAME
        @docker_compose_keycloak_postgres_service_name = AbasKeycloak::Constants::DOCKER_COMPOSE_KEYCLOAK_POSTGRES_SERVICE_NAME
        @DerivedConstants = AbasKeycloak::DerivedConstants.new(config: @config, host: @host).freeze
        @master_realm_endpoint          = @DerivedConstants.master_realm_endpoint
        @webserver_base_url = @config['webserver_base_url'] 
        @abas_bpm_clientid = AbasKeycloak::Constants::ABAS_BPM_CLIENTID
        @abas_webclient_clientid = AbasKeycloak::Constants::ABAS_WEBCLIENT_CLIENTID
        @abas_dashboard_clientid = AbasKeycloak::Constants::ABAS_DASHBOARD_CLIENTID
        @abas_gui_clientid = AbasKeycloak::Constants::ABAS_GUI_CLIENTID
        @abas_user_management_service_clientid = AbasKeycloak::Constants::ABAS_USER_MANAGEMENT_SERVICE_CLIENTID
    end

    def certificate_subject_value
      certificate_subject = @config['certificate_subject']
      if certificate_subject.nil? || certificate_subject.empty?
        return "/CN=#{@host['Properties']['hostname']}"
      else
        # If abasfile parameter defined a CN value, remove it, we want to autogenerate the hostname for it.
        if certificate_subject.include?('CN=')
          # Replace string with capture group 1 and group 3 without CN key value
          certificate_subject.gsub!( /(.*?)(\/CN=[^\/]*)(.*)/ ,'\1\3')
        end
        return certificate_subject + "/CN=#{@host['Properties']['hostname']}"
      end
    end

    def redirect_uri
      redirect_uri = '"' + @webserver_base_url + '/*"' 
      result = @webserver_base_url.split(':')
      if ( result[2] == nil || result[2] == '' )
        if result[0] == 'http' 
          redirect_uri = redirect_uri + "," + '"' + @webserver_base_url + ':80/*"'
        elsif result[0] == 'https' 
          redirect_uri = redirect_uri + "," + '"' + @webserver_base_url + ':443/*"'
        end
      end
      return redirect_uri
    end
  end
end