# abas_keycloak.rb
require File.join(File.dirname(__FILE__), '..', 'constants')

module AbasKeycloak
  class Main
    def initialize(id_hash)
      @id_hash = id_hash
      @install_dir = id_hash['install_dir']

      if exists?
        @docker_compose_file = DockerUtil.read_docker_compose(@install_dir)
        @service_postgres = @docker_compose_file['services'][Constants::DOCKER_COMPOSE_KEYCLOAK_POSTGRES_SERVICE_NAME]
        @service_keycloak = @docker_compose_file['services'][Constants::DOCKER_COMPOSE_KEYCLOAK_SERVICE_NAME]
      else
        @docker_compose_file = {}
        @service_postgres = {}
        @service_keycloak = {}
      end
    end

    def exists?
      # check if docker-compose exists
      File.file?(File.join(@install_dir, '/docker-compose.yml'))
    end

    def product_version
      return File.read("#{@install_dir}/VERSION").strip
    end

    def http_port
      lookup_mapped_port(@service_keycloak, 8080)
    end

    def https_port
      lookup_mapped_port(@service_keycloak, 8443)
    end

    private

    # Looks up the source port in a port mapping.
    #
    # @param [Hash] service A Docker Compose service description
    # @param [Integer] port_destination The port number to lookup
    #
    # @return [String] the mapped port if given in the service description,
    #           `Not mapped' otherwise
    def lookup_mapped_port(service, port_destination)
      port_mapping(service).invert.fetch(port_destination.to_s, 'Not mapped')
    end

    # Reads a string -> string hash from the port mapping specification of a
    # service.
    #
    # @param [Hash] service a Docker Compose service description
    # @return [Hash] the port mapping
    def port_mapping(service)
      return {} unless service.key? 'ports'

      service['ports']
          .map { |entry| entry.split(':') }
          .select { |pair| pair.size == 2 }
          .to_h
    end
  end

  class DockerUtil
    def self.read_docker_compose(path)
      docker_compose_path = File.join(path, "/docker-compose.yml")
      YAML.load_file(docker_compose_path)
    end
  end
end
