define license_controller::install($data) {
  $license_controller_installer_api_version = '2'
  $module_version          = $data['metadata']["Version"]

  $config                  = $data['config']
  $product_version         = $data['version']
  $extra_hosts             = $data['hosts']

  $install_dir             = $config['install_dir']
  $project_name            = $config['project_name']
  $user                    = $config['user']
  $aws_access_key_id       = $config['tenant_identity']['aws_access_key_id']
  $aws_secret_access_key   = $config['tenant_identity']['aws_secret_access_key']
  $port                    = $config['port']
  $log_level               = $config['loglevel']
  $stage                   = $config['stage']
  $docker_image            = "docker.registry.abas.sh/license-controller:${product_version}"

  $authentication          = $config['authentication']
  if ($authentication != undef) and ($authentication["registry_credentials"] != undef) {
    $registry_credentials  = abas::credentials($authentication["registry_credentials"])
    $registry_username     = $registry_credentials["username"]
    $registry_password     = $registry_credentials["password"]
  } else {
    $registry_username     = ''
    $registry_password     = ''
  }

  exec { 'Change ownership of install directory':
    command => "chown -R ${user} ${install_dir}",
    path    => '/usr/bin:/bin:/usr/local/bin',
    cwd     => $install_dir,
  }

  -> file { "${install_dir}/VERSION":
    ensure  => file,
    content => template('license_controller/VERSION.erb'),
    mode    => '0500',
    owner   => $user,
  }

  -> file { "${install_dir}/docker-compose.yml":
    ensure  => file,
    content => template('license_controller/docker-compose.yml.erb'),
    owner   => $user,
  }

  -> file { "${install_dir}/.env":
    ensure  => file,
    content => template('license_controller/.env.erb'),
    owner   => $user,
  }

  -> file { "${install_dir}/service-defaults.env":
    ensure  => file,
    content => template('license_controller/service-defaults.env.erb'),
    owner   => $user,
  }

  -> file { "${install_dir}/service.sh":
    ensure  => file,
    content => template('license_controller/service.sh.erb'),
    mode    => '0500',
    owner   => $user,
  }

  -> exec { 'DOCKER: Login user to docker.registry.abas.sh':
    onlyif    => ["[ -n '${registry_username}' ] && [ -n '${registry_password}' ]"],
    command   => "docker login docker.registry.abas.sh -u '${registry_username}' -p '${registry_password}'",
    logoutput => true,
    user      => $user,
    path      => '/usr/bin',
  }

  -> exec { 'Run the license controller service':
    command   => './service.sh --up',
    path      => "/usr/bin:/bin:/usr/local/bin:${install_dir}",
    cwd       => $install_dir,
    user      => $user,
    logoutput => true,
  }

  -> exec { 'DOCKER: Logout from docker.registry.abas.sh':
    onlyif    => ["[ -n '${registry_username}' ] && [ -n '${registry_password}' ]"],
    command   => 'docker logout docker.registry.abas.sh',
    logoutput => true,
    user      => $user,
    path      => '/usr/bin',
  }
}
