# These are common tasks required by install and update steps
define mongodb::common_install_update($data) {

  $config                   = $data['config']
  $install_dir              = $config['install_dir']
  $user                     = $config['user']
  $project_name             = $config['project_name']
  $module_version           = $data['metadata']['Version']
  # mongodb is internally versioned in abas docker.registry.abas.sh as well
  $product_version          = $data['version']
  $mongodb_abas_image          = "docker.registry.abas.sh/abas-mongodb:${product_version}"
  $mongodb_admin_credentials   = abas::credentials($data['config']['mongodb_admin_credentials'])
  $mongodb_admin_username = $mongodb_admin_credentials['username']
  $mongodb_admin_password = $mongodb_admin_credentials['password']

  $container_data_dir           = '/data/db'
  $mongodb_db_dir             = $data['extras']['mongodb_db_dir']
  $container_mongodb_initd_dir  = $data['extras']['container_mongodb_initd_dir']
  $mongodb_initd_dir            = $data['extras']['mongodb_initd_dir']
  $mongodb_mkdirs               = [ $mongodb_initd_dir, $mongodb_db_dir ]

  $mongo_db_port           = $config['mongo_db_port']
  $mongo_express_port      = $config['mongo_express_port']

  $install_mongoexpress    = $config['install_mongoexpress']
  $docker_compose_mongodb_service_name = $data['extras']['docker_compose_mongodb_service_name']
  $docker_compose_mongodb_exp_service_name = $data['extras']['docker_compose_mongodb_exp_service_name']

  $databases_resolved      = $data['extras']['databases_resolved']

  file { $mongodb_mkdirs:
    ensure => 'directory',
    owner  => 999,
    group  => 999,
    mode   => '0775',
  }

  -> file { "${install_dir}/mongo-express.env":
    ensure  => file,
    content => template('mongodb/mongo-express.env.erb'),
    owner   => $user,
    mode    => '0400',
  }

  -> file { "${install_dir}/mongodb.env":
    ensure  => file,
    content => template('mongodb/mongodb.env.erb'),
    owner   => $user,
    mode    => '0400',
  }

  -> file { "${install_dir}/docker-compose.yml":
      ensure  => file,
      content => template('mongodb/docker-compose.yml.erb'),
      owner   => $user,
      mode    => '0400',
  }

  -> file { "${install_dir}/.env":
    ensure  => file,
    content => template('mongodb/.env.erb'),
    owner   => $user,
    mode    => '0400',
  }

  -> file { "${mongodb_initd_dir}/create_db_and_user.js":
    ensure  => file,
    content => template('mongodb/create_db_and_user.js.erb'),
    owner   => 999,
    group   => 999,
    mode    => '0400',
  }

  -> file { "${install_dir}/.version":
    ensure  => file,
    content => template('mongodb/.version.erb'),
    mode    => '0440',
    owner   => $user,
  }

  -> file { "${install_dir}/VERSION":
    ensure  => file,
    content => template('mongodb/VERSION.erb'),
    mode    => '0440',
    owner   => $user,
  }
}
