# The main mongodb manifest file
class mongodb(String $module_id) {

  $data = abas::inspect($module_id)

  $path           = $data['config']['name']
  $config                 = $data['config']
  # The directories and paths that we will use on the host system where we are installing the module
  $install_dir             = $config['install_dir']
  $databases               = $config['databases']
  $mongodb_initd_dir       = $data['extras']['mongodb_initd_dir']
  $user                    = $config['user']

  $authentication     = $data['config']['authentication']
  if ($authentication != undef) and ($authentication["registry_credentials"] != undef) {
      $registry_credentials   = abas::credentials($authentication["registry_credentials"])
      $registry_username      = $registry_credentials["username"]
      $registry_password      = $registry_credentials["password"]
  } else {
      $registry_username      = ''
      $registry_password      = ''
  }

  exec {'Creating installation directory':
    command => "mkdir -p ${install_dir}",
    onlyif  => "test ! -d ${install_dir}",
    path    => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
  }
  -> user { "Creating ${user}":
    ensure     => 'present',
    name       => $user,
    managehome => true,
    groups     => ['docker'],
  }

  -> mongodb::common_install_update { 'Install the mongodb(common steps)':
    data    => $data,
  }

  -> exec { 'DOCKER: Login user to docker.registry.abas.sh':
    onlyif    => ["[ -n '${registry_username}' ] && [ -n '${registry_password}' ]"],
    command   => "docker login docker.registry.abas.sh -u '${registry_username}' -p '${registry_password}'",
    logoutput => true,
    user      => $user,
    path      => '/usr/bin',
  }

  exec { 'Start the Mongodb':
    command   => 'docker-compose up -d --force-recreate',
    cwd       => $install_dir,
    user      => $user,
    path      => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
    logoutput => true,
    require   => Mongodb::Common_install_update['Install the mongodb(common steps)'],
  }
}
