# The update mongodb class
class mongodb::update(String $module_id) {

  $data                  = abas::inspect($module_id)
  $config                = $data['config']
  $install_dir           = $config['install_dir']
  $databases             = $config['databases']
  $user                  = $config['user']
  $docker_compose_mongodb_service_name = $data['extras']['docker_compose_mongodb_service_name']
  $container_mongodb_initd_dir = $data['extras']['container_mongodb_initd_dir']

  exec {'DOCKER: Stop and remove containers':
    command   => 'docker-compose down || :',
    cwd       => $install_dir,
    path      => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
    user      => $user,
    logoutput => 'on_failure'
  }

  -> mongodb::common_install_update { 'Install the mongodb(common steps)':
    data    => $data,
  }

  -> exec { 'Start the Mongodb':
    command   => 'docker-compose up -d --force-recreate',
    cwd       => $install_dir,
    user      => $user,
    path      => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
    logoutput => true,
    require   => Mongodb::Common_install_update['Install the mongodb(common steps)'],
  }

  -> exec { 'Sleep wait for server':
    command   => 'sleep 5s',
    path      => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
    logoutput => 'on_failure',
  }

  -> exec { 'Create databases in mongo db':
    command   => "docker-compose exec -e COMPOSE_INTERACTIVE_NO_CLI=1 -T ${docker_compose_mongodb_service_name} bash -c '/usr/bin/mongo < ${container_mongodb_initd_dir}/create_db_and_user.js'" ,
    cwd       => $install_dir,
    user      => $user,
    path      => '/usr/bin:/usr/sbin:/bin:/usr/local/bin',
    logoutput => true,
    require   => Exec['Start the Mongodb'],
  }
}
