# Common install update steps for rest_api
define rest_api::install($data) {

  $config         = $data['config']
  $path           = $config['name']
  $module_version = $data['metadata']['Version']
  $product_version= $data['version']

  $install_dir    = $config['install_dir']
  $user           = $config['user']
  $docker_image   = "docker.registry.abas.sh/mw:${product_version}"

  $service_ip     = $config['service_ip']
  $access_log_max_history_days = $config['access_log_max_history_days']
  $access_log_max_total_size = $config['access_log_max_total_size']
  $oauth2_jwks_uri = $data['extras']['oauth2_jwks_uri']
  $oauth2_audience = $data['extras']['oauth2_audience']
  $oauth2_issuers  = $data['extras']['oauth2_issuers']

  $port = $data['extras']['port']
  $project_name = $config['project_name']
  $extra_hosts = $data['hosts']
  $external_docker_network = $config['external_docker_network']
  $authentication     = $config['authentication']
  if ($authentication != undef) and ($authentication["registry_credentials"] != undef) {
    $registry_credentials   = abas::credentials($authentication["registry_credentials"])
    $registry_username      = $registry_credentials["username"]
    $registry_password      = $registry_credentials["password"]
  } else {
    $registry_username      = ''
    $registry_password      = ''
  }

  file { "${install_dir}/VERSION":
    ensure  => file,
    content => template('rest_api/VERSION.erb'),
    mode    => '0500',
    owner   => $user,
  }
  -> file { "${install_dir}/docker-compose.yml":
    ensure  => file,
    content => template('rest_api/docker-compose.yml.erb'),
    owner   => $user,
  }
  -> file { "${install_dir}/.env":
    ensure  => file,
    content => template('rest_api/.env.erb'),
    owner   => $user,
  }
  -> file { "${install_dir}/service-defaults.env":
    ensure  => file,
    content => template('rest_api/service-defaults.env.erb'),
    owner   => $user,
  }
  -> file { "${install_dir}/service.sh":
    ensure  => file,
    content => template('rest_api/service.sh.erb'),
    mode    => '0500',
    owner   => $user,
  }
  -> file { "${install_dir}/abasconfig/logback.xml":
    ensure  => file,
    content => template('rest_api/logback.xml.erb'),
    owner   => $user,
  }
  -> file { "${install_dir}/application.properties":
    ensure  => file,
    content => template('rest_api/application.properties.erb'),
    owner   => $user,
  }
  -> tidy { 'delete-erp-configurations':
    path    => "${install_dir}/abasconfig",
    recurse => true,
    matches => [ 'erp.connection-*.cfg' ],
    rmdirs  => false,
  }
  -> tidy { 'delete-search-engine-configurations':
    path    => "${install_dir}/abasconfig",
    recurse => true,
    matches => [ 'search.service-*.cfg' ],
    rmdirs  => false,
  }
  -> rest_api::erp_connections { 'connections':
    clients                      => $config['clients'],
    install_dir                  => $install_dir,
    user                         => $user,
  }
  -> rest_api::fulltext_search { 'fulltext_search':
    fulltext_search              => $config['fulltext_search'],
    install_dir                  => $install_dir,
    user                         => $user,
  }
  -> exec { 'DOCKER: Login user to docker.registry.abas.sh':
    onlyif    => ["[ -n '${registry_username}' ] && [ -n '${registry_password}' ]"],
    command   => "docker login docker.registry.abas.sh -u '${registry_username}' -p '${registry_password}'",
    logoutput => true,
    user      => $user,
    path      => '/usr/bin',
  }
  -> exec { 'Run rest_api container':
    command   => "./service.sh --up",
    path      => "/usr/bin:/bin:/usr/local/bin:${install_dir}",
    cwd       => $install_dir,
    user      => $user,
    logoutput => true,
  }
  -> exec { 'DOCKER: Logout from docker.registry.abas.sh':
    onlyif    => ["[ -n '${registry_username}' ] && [ -n '${registry_password}' ]"],
    command   => 'docker logout docker.registry.abas.sh',
    logoutput => true,
    user      => $user,
    path      => '/usr/bin',
  }

}
