module AbasRest_api
  class Outputs

    def initialize(module_data)
      @config = module_data['config']
      @host   = module_data['host']
    end

    def protocol
      return "http"
    end

    def path
      path = @config['servlet_context_path'].dup
      path.sub!(/^\//, '')
      path.sub!(/\/$/, '')
      return path
    end

    def host
      host = @host['Properties']['hostname']
      if @config['service_ip'] != '0.0.0.0'
        host = @config['service_ip']
      end
      return host
    end

    def host_ip
      host_ip = @host['Properties']['ip']
      # Technically this should be the same as ip set in abas-installer Host section
      if @config['service_ip'] != '0.0.0.0'
        host_ip = @config['service_ip']
      end
      return host_ip
    end

    def port
      port = @config['port']
      # This does not work because the configuration
      # is resolved before the installation starts.
      # This way dynamic outputs (like dynamic ports)
      # are impossible.
      #
      # if port == 0
      #   Dir.chdir(@config['install_dir']) {
      #     port = `./rest-api.sh --port 2>/dev/null | cut -d: -f2`
      #   }
      # end
      return port
    end

    def rest_client_urls
      burl = base_url
      mapping = Hash.new
      @config['clients'].each do |client|
        id = client['client'].resolve('ai_identifier')
        client_id = client['id']
        if client_id == nil
          client_id = client['client'].resolve('mname')
        end
        mapping[id] = "#{burl}/r/#{client_id}"
      end
      return mapping
    end

    def ws_client_urls
      mapping = Hash.new
      if @config['enable_web_sockets'] != true
        return mapping
      end
      burl = base_url
      @config['clients'].each do |client|
        id = client['client'].resolve('ai_identifier')
        client_id = client['id']
        if client_id == nil
          client_id = client['client'].resolve('mname')
        end
        mapping[id] = "#{burl}/ws/#{client_id}/wedp"
      end
      return mapping
    end

    def base_url
      host = host()
      port = port()
      protocol = protocol()
      path = path()
      return "#{protocol}://#{host}:#{port}/#{path}"
    end

  end
end
