# abas_user_administration.rb

module AbasUser_administration
  class Main
    def initialize(id_hash)
      @install_dir = id_hash['install_dir']
      @name = id_hash['name']
      if exists?
        @docker_compose = loadDockerCompose
      else
        @docker_compose = {}
      end
    end

    def product_version
      return File.read("#{@install_dir}/VERSION").strip
    end

    def exists?()
      if (File.file?(File.join(@install_dir, "/service.sh")) &&
          File.file?(File.join(@install_dir, "/VERSION")) &&
          File.file?(File.join(@install_dir, "/docker-compose.yml")) &&
          File.file?(File.join(@install_dir, "/service-defaults.env")))
        return true
      end
      return false
    end

    def user
      if File.exists?("#{@install_dir}")
        uid = File.stat("#{@install_dir}").uid
        return Etc.getpwuid(uid).name
      end
      return "Install directory not found."
    end

    def port
      return @docker_compose.dig('services', 'user-administration', 'ports')[0].split(':')[0]
    end

    def project_name
      return `COMPOSE_PROJECT_NAME=unknown && source "#{@install_dir}/.env" && echo $COMPOSE_PROJECT_NAME`
    end

    def external_docker_network
      return @docker_compose.dig('networks', 'default', 'external', 'name')
    end

    def keycloak_admin_credentials
      return "Factlibs of dependencies not implemented in abas-installer"
    end

    def authentication
      return "Factlibs of dependencies not implemented in abas-installer"
    end

    def oauth2
      return "Factlibs of dependencies not implemented in abas-installer"
    end

    private

    def loadDockerCompose
      begin
        return YAML.load_file(File.join(@install_dir, "/docker-compose.yml"))
      rescue
        return {}
      end
    end
  end
end
