# The user administration install update manifest
define user_administration::install_templates_and_run($data) {

  $config         = $data['config']
  $extra_hosts    = $data['hosts']
  $module_version = $data['metadata']['Version']
  $path           = $config['name']
  $product_version= $data['version']

  $install_dir      = $config['install_dir']
  $user             = $config['user']
  $port             = $config['port']
  $project_name     = $config['project_name']
  $docker_image     = "docker.registry.abas.sh/tenant-administration-onprem:${product_version}"
  $external_docker_network = $config['external_docker_network']

  $oauth2_base_url = $config['oauth2']['base_url']
  $issuer = $config['oauth2']['issuer']

  $keycloak_realm = $config['oauth2']['keycloak_realm']
  $keycloak_admin_credentials = $data['config']['keycloak_admin_credentials']
  $keycloak_admin_credentials_resolved = abas::credentials($keycloak_admin_credentials)
  $keycloak_admin_username    = $keycloak_admin_credentials_resolved["username"]
  $keycloak_admin_password    = $keycloak_admin_credentials_resolved["password"]
  $kc_abas_user_management_service = $data['extras']['kc_abas_user_management_service']

  $authentication             = $config['authentication']
  if ($authentication != undef) and ($authentication["registry_credentials"] != undef) {
      $registry_credentials   = abas::credentials($authentication["registry_credentials"])
      $registry_username      = $registry_credentials["username"]
      $registry_password      = $registry_credentials["password"]
  } else {
      $registry_username      = ''
      $registry_password      = ''
  }

  file { "${install_dir}/VERSION":
    ensure  => file,
    content => template('user_administration/VERSION.erb'),
    mode    => '0500',
    owner   => $user,
  }

  ->file { "${install_dir}/docker-compose.yml":
    ensure  => file,
    content => template('user_administration/docker-compose.yml.erb'),
    owner   => $user,
  }

  -> file { "${install_dir}/.env":
    ensure  => file,
    content => template('user_administration/.env.erb'),
    owner   => $user,
  }

  -> file { "${install_dir}/service-defaults.env":
    ensure  => file,
    content => template('user_administration/service-defaults.env.erb'),
    owner   => $user,
  }

  -> file { "${install_dir}/service.sh":
    ensure  => file,
    content => template('user_administration/service.sh.erb'),
    owner   => $user,
    group   => 'docker',
    mode    => '0500',
  }

  -> file { "${install_dir}/logback-spring.xml":
    ensure  => file,
    content => template('user_administration/logback-spring.xml.erb'),
    owner   => $user,
  }

  -> file { "${install_dir}/application.properties":
    ensure  => file,
    content => template('user_administration/application.properties.erb'),
    owner   => $user,
  }

  -> file { "${install_dir}/get_client_credentials.sh":
    ensure  => file,
    content => template('user_administration/get_client_credentials.sh.erb'),
    owner   => $user,
    mode    => '0500',
  }

  -> exec { 'Get client credentials':
    command     => 'get_client_credentials.sh',
    path        => "/usr/bin:/bin:/usr/local/bin:${install_dir}",
    environment =>  [ "KC_MASTER_ADMIN_USERNAME=${keycloak_admin_username}", "KC_MASTER_ADMIN_PASSWORD=${keycloak_admin_password}"],
    cwd         => $install_dir,
    user        => $user,
  }

  -> exec { 'DOCKER: Login user to docker.registry.abas.sh':
    onlyif    => ["[ -n '${registry_username}' ] && [ -n '${registry_password}' ]"],
    command   => "docker login docker.registry.abas.sh -u '${registry_username}' -p '${registry_password}'",
    logoutput => true,
    user      => $user,
    path      => '/usr/bin',
  }

  -> exec { 'run service.sh':
    command => "service.sh --up",
    path    => "/usr/bin:/bin:/usr/local/bin:${install_dir}",
    cwd     => $install_dir,
    user    => $user,
  }

  -> exec { 'DOCKER: Logout from docker.registry.abas.sh':
    onlyif    => ["[ -n '${registry_username}' ] && [ -n '${registry_password}' ]"],
    command   => 'docker logout docker.registry.abas.sh',
    logoutput => true,
    user      => $user,
    path      => '/usr/bin',
  }
}
