module AbasWebclient
  class CheckFactory

    def initialize(data)
      @config = data['config']
      @install_dir = @config['install_dir']
      @registry_credentials = Abas::Credentials.load(@config['registry_credentials'])
    end

    def screen_service_port_free_check()
      Abas::PortCheck.create(
        name: "Check if screen service port is free", 
        port: @config['screen_srv_port'], 
        free: true)
    end

    def menu_service_port_free_check()
      Abas::PortCheck.create(
        name: "Check if menu service port is free", 
        port: @config['ucm_srv_port'], 
        free: true)
    end

    def activitiy_service_port_free_check()
      Abas::PortCheck.create(
        name: "Check if activitiy service port is free", 
        port: @config['activity_srv_port'], 
        free: true)
    end

    def prefs_service_port_free_check()
      Abas::PortCheck.create(
        name: "Check if preferences service port is free", 
        port: @config['prefs_srv_port'], 
        free: true)
    end

    def elastic_search_service_port1_free_check()
      Abas::PortCheck.create(
        name: "Check if elastic_search service port is free", 
        port: @config['elastic_search_port1'], 
        free: true)
    end

    def elastic_search_service_port2_free_check()
      Abas::PortCheck.create(
        name: "Check if elastic_search service port is free", 
        port: @config['elastic_search_port2'], 
        free: true)
    end

    def install_dir_exists_check()
      Abas::FileCheck.create(
        name: "Check if install_dir exists", 
        path: @config['install_dir'], 
        should_exist: true)
    end

    def install_dir_not_exists_check()
      Abas::FileCheck.create(
        name: "Check if install_dir does not exist", 
        path: @config['install_dir'], 
        should_exist: false)
    end

    def screen_service_running_check()
      Abas::DockerContainerRunningCheck.create(
        name: "Check if screen service is running",
        container_name: "#{@config['context_path']}_screenService"
      )
    end

    def menu_service_running_check()
      Abas::DockerContainerRunningCheck.create(
        name: "Check if menu service is running",
        container_name: "#{@config['context_path']}_ucmService"
      )
    end

    def activity_service_running_check()
      Abas::DockerContainerRunningCheck.create(
        name: "Check if activity service is running",
        container_name: "#{@config['context_path']}_activityService"
      )
    end

    def userPrefs_service_running_check()
      Abas::DockerContainerRunningCheck.create(
        name: "Check if user preferences service is running",
        container_name: "#{@config['context_path']}_userPreferencesService"
      )
    end

    def elasticSearch_service_running_check()
      Abas::DockerContainerRunningCheck.create(
        name: "Check if elastic search service is running",
        container_name: "#{@config['context_path']}_elasticSearch"
      )
    end

    def config_menu_service_exists_check()
      Abas::FileCheck.create(
        name: "Check if config_menu_service.json exists",
        path: "#{@install_dir}/config_menu_service.json",
        should_exist: true
      )
    end

    def config_screen_service_exists_check()
      Abas::FileCheck.create(
        name: "Check if config_screen_service.json exists",
        path: "#{@install_dir}/config_screen_service.json",
        should_exist: true
      )
    end

    def docker_compose_exists_check()
      Abas::FileCheck.create(
        name: "Check if docker-compose.yml exists",
        path: "#{@install_dir}/docker-compose.yml",
        should_exist: true
      )
    end

    def webclient_version_exists_check()
      Abas::FileCheck.create(
        name: "Check if webclient-version.yml exists",
        path: "#{@install_dir}/webclient-version.yml",
        should_exist: true
      )
    end

    def disk_space_check()
      Abas::DiskCheck.create(
        name: "Check if install_dir has enough free space",
        path: @config['install_dir'],
        required_mb: 1024 * 2,
        recommended_mb: 1024 * 10
      )
    end

    def credential_check()
      Abas::CredentialCheck.create(
        name: "Check if credentials are valid",
        username: @registry_credentials['username'],
        password: @registry_credentials['password'],
      )
    end

  end
end