# abas_webclient.rb
require 'yaml'
require 'json'

module AbasWebclient
  class Main
    def initialize(id_hash)
        @install_dir = id_hash['install_dir']

        if exists?
            @docker_compose = DockerComposeUtil.read_yaml(@install_dir, "/docker-compose.yml")
            @screen_srv_config = @docker_compose['services']['screen_service']
            @prefs_srv_config = @docker_compose['services']['prefs']
            @ucm_srv_config = @docker_compose['services']['ucm_service']
            @activity_srv_config = @docker_compose['services']['activity_service']
            @webclient_version = DockerComposeUtil.read_yaml(@install_dir, "/webclient-version.yml")
        end
    end

    def exists?
        return File.file?(File.join(@install_dir, "/webclient-version.yml"))
    end

    def screen_srv_port
        return DockerComposeUtil.get_port(@screen_srv_config)
    end

    def ucm_srv_port
        return DockerComposeUtil.get_port(@ucm_srv_config)
    end

    def activity_srv_port
        return DockerComposeUtil.get_port(@activity_srv_config)
    end

    def prefs_srv_port
        return DockerComposeUtil.get_port(@prefs_srv_config)
    end

    def version
        return @webclient_version['version']
    end
  end

  class DockerComposeUtil
    def self.read_yaml(install_dir, file)
        file_path = File.join(install_dir, file)
        return YAML.load_file(file_path)
    end

    def self.get_port(file)
        return file['ports'][0].split(":")[0]
    end

    def self.get_version(file)
        return file['image'].split(":")[1]
    end
  end

  class JsonUtil
    def self.read_json(install_dir, filename)
        file_path = File.join(install_dir, filename)
        file = File.open(file_path)
        return JSON.parse(file.read)
    end

    def self.get_port(file, portname)
        return file[portname]
    end
  end

  class PropertiesUtil
    def self.read_properties_file(install_dir, file)
        file_path = File.join(install_dir, file)
        return File.open(file_path)
    end

    def self.get_port(file, portname)
        file.each do |line|
            key, value = line.split("=")
            if key == portname
                return value.gsub("\n", '')
            end
        end
    end
  end
end
