module AbasWebserver
  require File.join(File.dirname(__FILE__), 'constants')
  class ConfigurationJsonBuilder

    def initialize(resolved_config: , host:)
      if resolved_config['oauth2'] !=nil
        @auth_base_url          = resolved_config['oauth2']['issuer']
        @audience               = resolved_config['oauth2']['audience']
      end
      @bpm                    = resolved_config['modules_to_host']['bpm']
      @webclient              = resolved_config['modules_to_host']['webclient']
      @rest_api               = resolved_config['modules_to_host']['rest_api']
      @dashboard              = resolved_config['modules_to_host']['dashboard']
      @user_administration    = resolved_config['modules_to_host']['user_administration']

      @webserver_base_url = AbasWebserver::Util.webserver_base_url( secure_mode: resolved_config['secure_mode'] , 
                                                                    hostname: host["Properties"]["hostname"], 
                                                                    http_port: resolved_config['http_port'], 
                                                                    https_port: resolved_config['https_port'])        
      @scheme                     = 'http'
    end

    def clients_and_api_json()
      @clientJsonString = Hash.new
      @apiJsonString = Hash.new
      @metaJsonString = Hash.new
      @metaJsonString.merge!( "audience" => "#{@audience}")
      @apiJsonString.merge!( "authBaseURL" => @auth_base_url)
      
      if @bpm != nil then
        @context_path_bpm = AbasWebserver::Constants::CONTEXT_PATH_BPM
        @apiJsonString.merge!( "workflowBaseURL" => "#{@webserver_base_url}/#{@context_path_bpm}")
        @clientJsonString.merge!( "abasBPM" => "abas-bpm")
      end
      
      if @webclient != nil then
        @context_path_screenservice   = @webclient['screen_srv_context_path']
        @context_path_ucmservice      = @webclient['ucm_srv_context_path']
        @context_path_prefsservice    = @webclient['prefs_srv_context_path']
        @context_path_activityservice = @webclient['activity_srv_context_path']
        
        @apiJsonString.merge!( "screenServiceV2BaseURL" => "#{@webserver_base_url}/#{@context_path_screenservice}")          
        @apiJsonString.merge!( "ucmServiceBaseURL" => "#{@webserver_base_url}/#{@context_path_ucmservice}")
        @apiJsonString.merge!( "prefsBaseURL" => "#{@webserver_base_url}/#{@context_path_prefsservice}")
        @apiJsonString.merge!( "activityBaseURL" => "#{@webserver_base_url}/#{@context_path_activityservice}")
        @clientJsonString.merge!( "webClient" => 'abas-webclient')
        @clientJsonString.merge!( "webUI" => 'abas-webui')
      end
      
      if @rest_api != nil then
        @apiJsonString.merge!( "erpBaseURL" => "#{@webserver_base_url}")
      end

      if @dashboard != nil then
        @apiJsonString.merge!( "dashboardBaseURL" => "#{@webserver_base_url}/#{@dashboard['context_path']}")
        @clientJsonString.merge!( "dashboard" => "dashboard")
      end

      if @user_administration != nil then
        @apiJsonString.merge!( "adminBaseURL" => "#{@webserver_base_url}/user-administration")
      end

      return @metaJsonString, @clientJsonString, @apiJsonString
    end
  end
end
