module AbasWebserver
  require 'json'
  require File.join(File.dirname(__FILE__), 'configuration_json_builder')
  require File.join(File.dirname(__FILE__), 'constants')
  require File.join(File.dirname(__FILE__), 'maven_artifact')
  class Extras
    attr_reader :webserver_dir, :webserver_conf_dir, :webserver_conf_file_path, :webserver_confd_dir, :webserver_abas_confd_dir,
                :webserver_abas_confd_dir_name, :webserver_default_www_conf_file_path, :certificates_dir, :webroot_dir, :backup_dir,
                :certificates_dir_name, :certificate_subject_value, :nginx_debug_command, :docker_compose_service_name, :context_path_bpm
                

    def initialize(module_data)
        @log = AbasLogger.instance 
        # eg: @log.debug() @log.info() 
        @config = module_data['resolved_config']
        @host   = module_data['host']

        @INSTALL_DIR      = @config['install_dir']
        @NGINX_DEFAULT_WWW_CONF_FILE_PATH = File.join(AbasWebserver::Constants::NGINX_CONF_PATH, AbasWebserver::Constants::NGINX_DEFAULT_WWW_CONF_FILENAME)
        @CONFIGURATION_JSON_BUILDER = AbasWebserver::ConfigurationJsonBuilder.new(resolved_config: @config, host: @host)
        @META_HASH, @CLIENTS_HASH, @API_HASH = @CONFIGURATION_JSON_BUILDER.clients_and_api_json
        
        @DerivedConstants = AbasWebserver::DerivedConstants.new(install_dir: @INSTALL_DIR,
                                                                project_name: @config['project_name'] )
        @webserver_dir                        = @DerivedConstants.WEBSERVER_DIR
        @webserver_conf_dir                   = @DerivedConstants.WEBSERVER_CONF_DIR
        @webserver_conf_file_path             = @DerivedConstants.WEBSERVER_CONF_FILE_PATH
        @webserver_confd_dir                  = @DerivedConstants.WEBSERVER_CONFD_DIR
        @webserver_abas_confd_dir_name        = AbasWebserver::Constants::WEBSERVER_ABAS_CONFD_DIR_NAME
        @webserver_abas_confd_dir             = @DerivedConstants.WEBSERVER_ABAS_CONFD_DIR     
        @webserver_default_www_conf_file_path = @DerivedConstants.WEBSERVER_DEFAULT_WWW_CONF_FILE_PATH
        @certificates_dir_name                = AbasWebserver::Constants::CERTIFICATES_DIR_NAME
        @certificates_dir                     = @DerivedConstants.CERTIFICATES_DIR
        @webroot_dir                          = @DerivedConstants.WEBROOT_DIR
        @backup_dir                           = @DerivedConstants.BACKUP_DIR
        @nginx_debug_command                  = AbasWebserver::Constants::NGINX_DEBUG_COMMAND
        @docker_compose_service_name          = AbasWebserver::Constants::DOCKER_COMPOSE_SERVICE_NAME
        @context_path_bpm                     = AbasWebserver::Constants::CONTEXT_PATH_BPM
    end

    def webserver_container_webroot_dir
      return AbasWebserver::Constants::NGINX_SHARE_HTML
    end

    def webserver_container_certificates_dir
      return AbasWebserver::Constants::NGINX_CERTIFICATES_DIR
    end

    def webserver_container_conf_file_path
      return AbasWebserver::Constants::NGINX_CONF_PATH
    end

    def webserver_container_default_www_conf_file_path
      return @NGINX_DEFAULT_WWW_CONF_FILE_PATH
    end 

    def webserver_container_confd_dir
      return AbasWebserver::Constants::NGINX_CONFD_DIR
    end

    def webserver_container_var_log_dir
      return AbasWebserver::Constants::NGINX_LOG_DIR
    end

    def maven_artifacts_array
      if ( @config['modules_to_host'] != nil )
        @maven_artifacts = Array.new
        @config['modules_to_host'].each do |key, value|
          if value != nil && value['webserver_artifact_coordinate'] != nil
            maven_artifact = AbasWebserver::MavenArtifact.new( module_name: key, repo_base_url: @config['repo_base_url'], maven_coordinate: value['webserver_artifact_coordinate'], web_context: value['context_path'] )
            @maven_artifacts << (maven_artifact.to_h())
          end
        end
        return @maven_artifacts
      end
      return nil
    end

    def webserver_backup_dir
      return File.join(@backup_dir, AbasWebserver::Constants::WEBSERVER_DIR_NAME + '-' + ::Time.new.strftime('%F_%H-%M-%S'))
    end
    
    def meta_json_string
      return JSON.pretty_generate(@META_HASH)
    end

    def clients_json_string
      return JSON.pretty_generate(@CLIENTS_HASH)
    end

    def api_json_string
      return JSON.pretty_generate(@API_HASH)
    end

    def certificate_subject_value
      certificate_subject = @config['certificate_subject']
      if certificate_subject.nil? || certificate_subject.empty?
        return "/CN=#{@host['Properties']['hostname']}"
      else
        # If abasfile parameter defined a CN value, remove it, we want to autogenerate the hostname for it.
        if certificate_subject.include?('CN=')
          # Replace string with capture group 1 and group 3 without CN key value
          certificate_subject.gsub!( /(.*?)(\/CN=[^\/]*)(.*)/ ,'\1\3')
        end
        return certificate_subject + "/CN=#{@host['Properties']['hostname']}"
      end
    end
  end
end