# abas_webserver.rb
require 'yaml'
require 'json'
require File.join(File.dirname(__FILE__), '../', 'constants')
require File.join(File.dirname(__FILE__), '../', 'derived_constants')

module AbasWebserver
  class Main
    def initialize(identifier_hash)
      @install_dir = identifier_hash['install_dir']
      @project_name = identifier_hash['project_name']
      @DerivedConstants = AbasWebserver::DerivedConstants.new(install_dir: @install_dir, project_name: @project_name).freeze
      @docker_compose_file_path = File.join(@DerivedConstants.DOCKER_COMPOSE_DIR, '/docker-compose.yml')
      @dc_webserver_section = read_compose_webserver_configuration
    end

    def exists?
      # Implicitly we are testing if install_dir is also present by below check as it is a parent folder.
      if (File.directory?(@DerivedConstants.WEBSERVER_DIR) && File.file?(@docker_compose_file_path))
        return true
      end
      return false
    end

    def product_version
      return File.read("#{@install_dir}/VERSION").strip
    end

    def user
      `stat -c "%U" #{@install_dir}`.strip
    end

    def http_port
      return get_host_port(container_port: '80')
    end

    def https_port
      return get_host_port(container_port: '443')
    end

    def secure_mode
      output = `grep -i 'listen 443' #{@DerivedConstants.WEBSERVER_DEFAULT_WWW_CONF_FILE_PATH} `
      if output.lines.count == 1
        return true
      else
        return false
      end
    end

    def debug_mode
      output = `grep -F "#{AbasWebserver::Constants::NGINX_DEBUG_COMMAND}" #{@docker_compose_file_path} `
      if output.lines.count == 1
        return true
      else
        return false
      end
    end

    def certificate_subject
      subject = `openssl x509 -noout -subject -in #{@DerivedConstants.CERTIFICATES_DIR}/*.crt`
      subject.gsub!("subject=", "/")
      subject.gsub!(" = ", "=")
      subject.gsub!(", ", "/")
      subject.gsub!(/(.*?)(\/CN=[^\/]*)(.*)/, '\1\3')
      return subject
    end

    def oauth2
      configuration_json = File.read("#{@DerivedConstants.WEBROOT_DIR}/configuration.json")
      configurationHash = JSON.parse(configuration_json)
      oauth2Hash = Hash.new
      if ("#{configurationHash['api']['authBaseURL']}".include? "realms")
        oauth2Hash.merge!("type" => "keycloak")
      else
        oauth2Hash.merge!("type" => "Unknown Authentication Server Type")
      end
      oauth2Hash.merge!("issuer" => "#{configurationHash['api']['authBaseURL']}")
      oauth2Hash.merge!("audience" => "#{configurationHash['meta']['audience']}")
      return oauth2Hash
    end

    private

    def get_host_port(container_port:)
      ports = @dc_webserver_section.fetch('ports', [])
      for index in 0...ports.size
        splitted_ports = ports[index].split(':')
        if splitted_ports[1].strip.to_s == container_port
          return splitted_ports[0]
        end
      end
      return 'Not in use.'
    end

    def read_compose_webserver_configuration
      if exists?
        docker_compose = read_docker_compose
        service = docker_compose.dig('services', AbasWebserver::Constants::DOCKER_COMPOSE_SERVICE_NAME)
        if service.nil?
          return {}
        else
          return service
        end
      else
        return {}
      end
    end

    def read_docker_compose
      begin
        return YAML.load_file(@docker_compose_file_path)
      rescue
        return {}
      end
    end
  end
end

